"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.DBRecordsArrayInstance = exports.DBRecordInstance = exports.DBRecordDraft = exports.DBRecordsBatchDraft = void 0;
const rest_api_proxy_js_1 = require("../api/rest-api-proxy.js");
const utils_js_1 = require("./utils.js");
class DBRecordsBatchDraft {
    constructor({ label, options = {
        returnResult: true,
        suggestTypes: true
    }, payload }) {
        this.label = label;
        this.options = options;
        this.payload = payload;
    }
    toJson() {
        return {
            label: this.label,
            options: this.options,
            payload: this.payload
        };
    }
}
exports.DBRecordsBatchDraft = DBRecordsBatchDraft;
class DBRecordDraft {
    constructor({ label, properties = [] }) {
        this.label = label;
        this.properties = properties;
    }
    toJson() {
        return {
            label: this.label,
            properties: this.properties
        };
    }
}
exports.DBRecordDraft = DBRecordDraft;
class DBRecordInstance extends rest_api_proxy_js_1.RestApiProxy {
    constructor(data) {
        super();
        this.data = data;
    }
    get id() {
        try {
            return this.data.__id;
        }
        catch (_a) {
            throw new Error(`DBRecordInstance: Unable to access 'id'. The Record data is undefined.`);
        }
    }
    get label() {
        try {
            return this.data.__label;
        }
        catch (_a) {
            throw new Error(`DBRecordInstance: Unable to access 'label'. The Record data is undefined.`);
        }
    }
    get proptypes() {
        try {
            return this.data.__proptypes;
        }
        catch (_a) {
            throw new Error(`DBRecordInstance: Unable to access 'proptypes'. The Record data' is undefined.`);
        }
    }
    get date() {
        try {
            return (0, utils_js_1.idToDate)(this.data.__id);
        }
        catch (_a) {
            throw new Error(`DBRecordInstance: Unable to access 'date'. The Record data is undefined.`);
        }
    }
    get timestamp() {
        try {
            return (0, utils_js_1.idToTimestamp)(this.data.__id);
        }
        catch (_a) {
            throw new Error(`DBRecordInstance: Unable to access 'timestamp'. The Record data is undefined.`);
        }
    }
    async delete(transaction) {
        if (!this.data) {
            throw new Error('DBRecordInstance: Unable to delete Record. The Record data is undefined.');
        }
        return await this.apiProxy.records.deleteById(this.data.__id, transaction);
    }
    async update(partialData, transaction) {
        if (!this.data) {
            throw new Error('DBRecordInstance: Unable to update Record. The Record data is undefined.');
        }
        return this.apiProxy.records.update(this.data.__id, partialData, transaction);
    }
    async set(data, transaction) {
        if (!this.data) {
            throw new Error('DBRecordInstance: Unable to set. The Record data is undefined.');
        }
        return this.apiProxy.records.set(this.data.__id, data, transaction);
    }
    async attach(target, options, transaction) {
        if (!this.data) {
            throw new Error('DBRecordInstance: Unable to attach Record. The Record data is undefined.');
        }
        return this.apiProxy.records.attach(this.data.__id, target, options, transaction);
    }
    async detach(target, options, transaction) {
        if (!this.data) {
            throw new Error('DBRecordInstance: Unable to detach Record. The Record data is undefined.');
        }
        return this.apiProxy.records.detach(this.data.__id, target, options, transaction);
    }
}
exports.DBRecordInstance = DBRecordInstance;
class DBRecordsArrayInstance extends rest_api_proxy_js_1.RestApiProxy {
    constructor(data, total, searchParams) {
        super();
        this.data = data;
        this.total = total;
        this.searchParams = searchParams;
    }
}
exports.DBRecordsArrayInstance = DBRecordsArrayInstance;
